{% load i18n %}

<div id="toast" class="fixed flex justify-center items-center w-full hidden">
    <div class="fixed bottom-0 mb-4 px-4">
        <div id="toast" class="flex w-full items-center rounded-lg p-4 shadow bg-gray-800 text-gray-400" role="alert">
            <div class="text-sm font-normal">{% trans 'Your comment has been sent. It will be shown if accepted by the admin.' %}</div>
            <button type="button" onclick="CloseToast()" class="ml-4 inline-flex h-8 w-8 rounded-lg p-1 text-gray-300 hover:text-white hover:bg-gray-700" data-dismiss-target="#toast" aria-label="OK">{% trans 'OK' context 'toast button' %}</button>
        </div>
    </div>
</div>
