<input type="hidden" name="app_name" value="{{ object_info.app_name }}" hidden>
<input type="hidden" name="object_id" value="{{ object_info.object_id }}" hidden>
<input type="hidden" name="model_name" value="{{ object_info.model_name }}" hidden>
<input type="hidden" name="content_type" value="{{ object_info.content_type }}" hidden>
<input type="hidden" name="settings_slug" value="{{ settings.slug }}" hidden>