{% load i18n %}
<div class="grid place-content-center">
    <div class="mb-16">
        {#1#}
        <div class="w-72 pt-4">
            <div class="-rotate-3 rounded-lg border-2 border-gray-200 bg-slate-50 p-2 shadow-xl">
                <div class="inline-block content-center">
                    <svg class="inline-block w-12 rounded-full fill-gray-300" aria-hidden="true" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
                        <path fill-rule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-6-3a2 2 0 11-4 0 2 2 0 014 0zm-2 4a5 5 0 00-4.546 2.916A5.986 5.986 0 0010 16a5.986 5.986 0 004.546-2.084A5 5 0 0010 11z" clip-rule="evenodd"></path>
                    </svg>
                    <span class="inline-block h-3 w-24 rounded-full bg-gray-300 ltr:ml-1 rtl:mr-1"></span>
                </div>
                <div class="flex flex-col space-y-2">
                    <div class="w-full rounded-full bg-gray-200 p-1.5"></div>
                    <div class="w-full rounded-full bg-gray-200 p-1.5"></div>
                </div>
            </div>
        </div>
        {#2#}
        <div class="translate-x-16 absolute w-64 -translate-y-16 rotate-3 scale-90 pt-4">
            <div class="rounded-lg border-2 border-gray-200 bg-slate-100 p-2 shadow-xl">
                <div class="inline-block content-center">
                    <svg class="inline-block w-12 rounded-full fill-gray-300" aria-hidden="true" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
                        <path fill-rule="evenodd" d="M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-6-3a2 2 0 11-4 0 2 2 0 014 0zm-2 4a5 5 0 00-4.546 2.916A5.986 5.986 0 0010 16a5.986 5.986 0 004.546-2.084A5 5 0 0010 11z" clip-rule="evenodd"></path>
                    </svg>
                    <span class="inline-block h-3 w-24 rounded-full bg-gray-300 ltr:ml-1 rtl:mr-1"></span>
                </div>
                <div class="flex flex-col space-y-2">
                    <div class="w-full rounded-full bg-gray-200 p-1.5"></div>
                    <div class="w-full rounded-full bg-gray-200 p-1.5"></div>
                </div>
            </div>
        </div>
    </div>
    <div class="text-center text-xl font-bold text-text-dark dark:text-text-light">{% trans 'No comment yet' %}</div>
</div>