{% load i18n %}
{% load comment_tags %}

<div class="my-4 border-b-4 border-section-primary-light dark:border-section-primary-dark pb-2">
  <span class="border-b-4 border-section-secondary-light dark:border-section-secondary-dark pb-2 font-semibold text-section-text-light dark:text-section-text-dark">
    <span class="px-2">{% trans 'Comments' %}</span>
      {% if count %}
          <span class="rounded-md bg-section-number-bg-light text-section-number-text-light dark:section-number-bg-dark dark:section-number-text-dark px-1">{{ count|number:1 }}</span>
      {% endif %}
  </span>
</div>