{% load static %}
{% load comment_tags %}

{% render_comment_import %}

{% get_settings 'LANGUAGE_CODE' as LANGUAGE_CODE %}

<div {% if settings.theme_dark_mode %} data-mode="dark" {% endif %} dir="{{ settings.theme_direction }}">
    <div id="comments" class="p-4 bg-background-light dark:bg-background-dark {% if LANGUAGE_CODE == 'fa-ir' %}font-default-fd{% endif %}">

        {# COMMENT MODAL #}
        <div id="comment-modal"></div>

        {# CREATE COMMENT FORM #}
        {% include 'comment/forms/comment_form_create.html' with settings=settings %}

        {# COMMENTS LIST #}
        <div id="comment-list">
            {% include 'comment/utils/comment_list_loader.html' %}
        </div>

    </div>
</div>
{% include 'comment/utils/toast.html' %}
{% include 'comment/utils/SCRIPTS.html' %}
