# Generated by Django 4.1.7 on 2023-04-06 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('comment', '0002_config'),
    ]

    operations = [
        migrations.AddField(
            model_name='comment',
            name='content_main',
            field=models.TextField(default=''),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='comment',
            name='status_edited',
            field=models.CharField(choices=[('n', 'None'), ('d', 'Delivered'), ('a', 'Accepted'), ('r', 'Rejected')], default='n', max_length=1),
        ),
        migrations.AddField(
            model_name='commentsettings',
            name='status_edited_check',
            field=models.BooleanField(default=False, help_text='If True, comment status_edited will be set as d(Delivered) otherwise it will be set as a(Accepted) when a comment is edited.'),
        ),
    ]
